--- doc/src/sgml/textsearch.sgml.orig	2008-01-11 22:20:16.000000000 +0100
+++ doc/src/sgml/textsearch.sgml	2008-01-11 22:27:57.000000000 +0100
@@ -418,16 +418,16 @@
    <para>
     It is possible to do full text search with no index.  A simple query
     to print the <structname>title</> of each row that contains the word
-    <literal>friend</> in its <structfield>body</> field is:
+    <literal>planet</> in its <structfield>body</> field is:
 
 <programlisting>
 SELECT title
-FROM pgweb
-WHERE to_tsvector('english', body) @@ to_tsquery('english', 'friend');
+FROM apod
+WHERE to_tsvector('english', body) @@ to_tsquery('english', 'planet');
 </programlisting>
 
-    This will also find related words such as <literal>friends</>
-    and <literal>friendly</>, since all these are reduced to the same
+    This will also find related words such as <literal>planets</>
+    and <literal>planetary</>, since all these are reduced to the same
     normalized lexeme.
    </para>
 
@@ -438,8 +438,8 @@
 
 <programlisting>
 SELECT title
-FROM pgweb
-WHERE to_tsvector(body) @@ to_tsquery('friend');
+FROM apod
+WHERE to_tsvector(body) @@ to_tsquery('planet');
 </programlisting>
 
     This query will use the configuration set by <xref
@@ -448,14 +448,14 @@
 
    <para>
     A more complex example is to
-    select the ten most recent documents that contain <literal>create</> and
-    <literal>table</> in the <structname>title</> or <structname>body</>:
+    select the ten most recent documents that contain <literal>comet</> and
+    <literal>tail</> in the <structname>title</> or <structname>body</>:
 
 <programlisting>
 SELECT title
-FROM pgweb
-WHERE to_tsvector(title || body) @@ to_tsquery('create &amp; table')
-ORDER BY last_mod_date DESC LIMIT 10;
+FROM apod
+WHERE to_tsvector(title || body) @@ to_tsquery('comet &amp; tail')
+ORDER BY sdate DESC LIMIT 10;
 </programlisting>
 
     For clarity we omitted the <function>coalesce</function> function
@@ -480,7 +480,7 @@
     linkend="textsearch-indexes">) to speed up text searches:
 
 <programlisting>
-CREATE INDEX pgweb_idx ON pgweb USING gin(to_tsvector('english', body));
+CREATE INDEX apod_idx ON apod USING gin(to_tsvector('english', body));
 </programlisting>
 
     Notice that the 2-argument version of <function>to_tsvector</function> is
@@ -510,10 +510,10 @@
     configuration name is specified by another column, e.g.:
 
 <programlisting>
-CREATE INDEX pgweb_idx ON pgweb USING gin(to_tsvector(config_name, body));
+CREATE INDEX apod_idx ON apod USING gin(to_tsvector(config_name, body));
 </programlisting>
 
-    where <literal>config_name</> is a column in the <literal>pgweb</>
+    where <literal>config_name</> is a column in the <literal>apod</>
     table.  This allows mixed configurations in the same index while
     recording which configuration was used for each index entry.  This
     would be useful, for example, if the document collection contained
@@ -526,7 +526,7 @@
     Indexes can even concatenate columns:
 
 <programlisting>
-CREATE INDEX pgweb_idx ON pgweb USING gin(to_tsvector('english', title || body));
+CREATE INDEX apod_idx ON apod USING gin(to_tsvector('english', title || body));
 </programlisting>
    </para>
 
@@ -538,24 +538,24 @@
     indexed when the other is <literal>NULL</>:
 
 <programlisting>
-ALTER TABLE pgweb ADD COLUMN textsearchable_index_col tsvector;
-UPDATE pgweb SET textsearchable_index_col =
+ALTER TABLE apod ADD COLUMN textsearch tsvector;
+UPDATE apod SET textsearch =
      to_tsvector('english', coalesce(title,'') || coalesce(body,''));
 </programlisting>
 
     Then we create a <acronym>GIN</acronym> index to speed up the search:
 
 <programlisting>
-CREATE INDEX textsearch_idx ON pgweb USING gin(textsearchable_index_col);
+CREATE INDEX textsearch_idx ON apod USING gin(textsearch);
 </programlisting>
 
     Now we are ready to perform a fast full text search:
 
 <programlisting>
 SELECT title
-FROM pgweb
-WHERE textsearchable_index_col @@ to_tsquery('create &amp; table')
-ORDER BY last_mod_date DESC LIMIT 10;
+FROM apod
+WHERE textsearch @@ to_tsquery('comet &amp; tail')
+ORDER BY sdate DESC LIMIT 10;
 </programlisting>
    </para>
 
@@ -594,8 +594,7 @@
    user query. Also, we need to return results in a useful order, so we need
    a function that compares documents with respect to their relevance to
    the query. It's also important to be able to display the results nicely.
-   <productname>PostgreSQL</productname> provides support for all of these
-   functions.
+   <productname>PostgreSQL</productname> provides all these functions.
   </para>
 
   <sect2 id="textsearch-parsing-documents">